MethodChannelCertifaceSdk class

Inheritance

Constructors

MethodChannelCertifaceSdk()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

askPermission() Future<bool>
override
checkPermission() Future<bool>
override
getPlatformVersion() Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startLiveness(String appKey, {String environment = 'HML', String provider = 'IPROOV', bool isCustomEnabled = false, Map<String, dynamic>? theme}) Future<Map<String, dynamic>>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited