CertifaceSdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CertifaceSdkPlatform
Implementers

Constructors

CertifaceSdkPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

askPermission() Future<bool>
checkPermission() Future<bool>
getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startLiveness(String appKey, {String environment = 'HML', String provider = 'IPROOV', bool isCustomEnabled = false, Map<String, dynamic>? theme}) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CertifaceSdkPlatform
getter/setter pair